@@ -359,14 +359,14 @@ mate_bg_load_from_gsettings (MateBG    *bg,
 
 		/* Fallback to default BG if the filename set is non-existent */
 		if (filename != NULL && !g_file_test (filename, G_FILE_TEST_EXISTS)) {
-			
+
 			g_free (filename);
-			
+
 			g_settings_delay (settings);
 			g_settings_reset (settings, MATE_BG_KEY_PICTURE_FILENAME);
 			filename = g_settings_get_string (settings, MATE_BG_KEY_PICTURE_FILENAME);
 			g_settings_revert (settings);
-			
+
 			//* Check if default background exists, also */
 			if (filename != NULL && !g_file_test (filename, G_FILE_TEST_EXISTS)) {
 				g_free (filename);
@@ -844,11 +844,19 @@ draw_color_each_monitor (MateBG    *bg,
 			 GdkPixbuf *dest,
 			 GdkScreen *screen)
 {
+#if GTK_CHECK_VERSION (3, 22, 0)
+	GdkDisplay *display;
+#endif
 	GdkRectangle rect;
 	gint num_monitors;
 	int monitor;
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+	display = gdk_screen_get_display (screen);
+	num_monitors = gdk_display_get_n_monitors (display);
+#else
 	num_monitors = gdk_screen_get_n_monitors (screen);
+#endif
 	for (monitor = 0; monitor < num_monitors; monitor++) {
 		gdk_screen_get_monitor_geometry (screen, monitor, &rect);
 		draw_color_area (bg, dest, &rect);
@@ -1021,7 +1029,14 @@ draw_each_monitor (MateBG    *bg,
 		   GdkPixbuf *dest,
 		   GdkScreen *screen)
 {
+#if GTK_CHECK_VERSION (3, 22, 0)
+	GdkDisplay *display;
+
+	display = gdk_screen_get_display (screen);
+	gint num_monitors = gdk_display_get_n_monitors (display);
+#else
 	gint num_monitors = gdk_screen_get_n_monitors (screen);
+#endif
 	gint monitor = 0;
 
 	for (; monitor < num_monitors; monitor++) {
@@ -1255,7 +1270,7 @@ make_root_pixmap (GdkWindow *window, gint width, gint height)
 		return NULL;
 	}
 
-	depth = DefaultDepth (display, gdk_screen_get_number (screen));
+	depth = DefaultDepth (display, gdk_x11_screen_get_screen_number (screen));
 	xpixmap = XCreatePixmap (display, GDK_WINDOW_XID (window), width, height, depth);
 
 	XFlush (display);
@@ -1409,7 +1424,7 @@ mate_bg_get_surface_from_root (GdkScreen *screen)
 	cairo_t *cr;
 
 	display = GDK_DISPLAY_XDISPLAY (gdk_screen_get_display (screen));
-	screen_num = gdk_screen_get_number (screen);
+	screen_num = gdk_x11_screen_get_screen_number (screen);
 
 	result = XGetWindowProperty (display,
 				     RootWindow (display, screen_num),
@@ -1448,8 +1463,8 @@ mate_bg_get_surface_from_root (GdkScreen *screen)
 		gdk_error_trap_pop_ignored ();
 	}
 
-	width = gdk_screen_get_width (screen);
-	height = gdk_screen_get_height (screen);
+	gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+				 &width, &height);
 
 	if (source_pixmap) {
 		surface = cairo_surface_create_similar (source_pixmap,
@@ -1490,7 +1505,7 @@ mate_bg_set_root_pixmap_id (GdkScreen       *screen,
 			    Display         *display,
 			    Pixmap           xpixmap)
 {
-	Window   xroot   = RootWindow (display, gdk_screen_get_number (screen));
+	Window   xroot   = RootWindow (display, gdk_x11_screen_get_screen_number (screen));
 	char    *atom_names[] = {"_XROOTPMAP_ID", "ESETROOT_PMAP_ID"};
 	Atom     atoms[G_N_ELEMENTS(atom_names)] = {0};
 
@@ -1581,7 +1596,7 @@ mate_bg_set_surface_as_root (GdkScreen *screen, cairo_surface_t *surface)
 	 */
 	Display    *display      = GDK_DISPLAY_XDISPLAY (gdk_screen_get_display (screen));
 	Pixmap      pixmap_id    = cairo_xlib_surface_get_drawable (surface);
-	Window      xroot        = RootWindow (display, gdk_screen_get_number (screen));
+	Window      xroot        = RootWindow (display, gdk_x11_screen_get_screen_number (screen));
 
 	XGrabServer (display);
 	mate_bg_set_root_pixmap_id (screen, display, pixmap_id);
@@ -2094,10 +2109,14 @@ scale_thumbnail (MateBGPlacement placement,
 	if (get_thumb_annotations (thumb, &o_width, &o_height)		||
 	    (filename && get_original_size (filename, &o_width, &o_height))) {
 
-		int scr_height = gdk_screen_get_height (screen);
-		int scr_width = gdk_screen_get_width (screen);
+		int scr_height;
+		int scr_width;
 		int thumb_width = gdk_pixbuf_get_width (thumb);
 		int thumb_height = gdk_pixbuf_get_height (thumb);
+
+		gdk_window_get_geometry (gdk_screen_get_root_window (screen), NULL, NULL,
+					 &scr_width, &scr_height);
+
 		double screen_to_dest = fit_factor (scr_width, scr_height,
 						    dest_width, dest_height);
 		double thumb_to_orig  = fit_factor (thumb_width, thumb_height,
