@@ -1678,11 +1678,12 @@ static char **
 make_environment_for_screen (GdkScreen  *screen,
 			     char      **envp)
 {
-	char **retval;
-	char **freeme;
-	char  *display_name;
-	int    display_index = -1;
-	int    i, env_len;
+	GdkDisplay *display;
+	char      **retval;
+	char      **freeme;
+	char       *display_name;
+	int         display_index = -1;
+	int         i, env_len;
 
 	g_return_val_if_fail (GDK_IS_SCREEN (screen), NULL);
 
@@ -1705,7 +1706,8 @@ make_environment_for_screen (GdkScreen  *screen,
 	retval = g_new (char *, env_len + 1);
 	retval [env_len] = NULL;
 
-	display_name = gdk_screen_make_display_name (screen);
+	display = gdk_screen_get_display (screen);
+	display_name = g_strdup (gdk_display_get_name (display));
 
 	for (i = 0; i < env_len; i++)
 		if (i == display_index)
@@ -1822,7 +1824,7 @@ ditem_execute (const MateDesktopItem *item,
 		const char *icon;
 
 		sn_context = sn_launcher_context_new (sn_display,
-						      screen ? gdk_screen_get_number (screen) :
+						      screen ? gdk_x11_screen_get_screen_number (screen) :
 						      DefaultScreen (GDK_DISPLAY_XDISPLAY (gdkdisplay)));
 
 		name = mate_desktop_item_get_localestring (item,
@@ -2078,10 +2080,17 @@ mate_desktop_item_launch_on_screen_with_env (
 			return -1;
 		}
 
+#if GTK_CHECK_VERSION (3, 22, 0)
+		retval = gtk_show_uri_on_window  (NULL,
+		                                  url,
+		                                  GDK_CURRENT_TIME,
+		                                  error);
+#else
 		retval = gtk_show_uri  (screen,
 					url,
 					GDK_CURRENT_TIME,
 					error);
+#endif
 		return retval ? 0 : -1;
 	}
 
